@@ -2,7 +2,8 @@
 This file is part of Swapspace.
 
 Copyright (C) 2005,2006, Software Industry Industry Promotion Agency (SIPA)
-Written by Jeroen T. Vermeulen <jtv@xs4all.nl>.
+Copyright (C) 2010, Jeroen T. Vermeulen
+Written by Jeroen T. Vermeulen.
 
 Swapspace is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -38,14 +39,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 
 static const char copyright[] = "\n"
-      "Copyright (c) 2004-2005 Software Industry Promotion Agency of Thailand\n"
-      "Written by Jeroen T. Vermeulen <jtv@sipa.or.th>\n"
+      "Copyright (c) 2004-2006 Software Industry Promotion Agency of Thailand\n"
+      "Copyright (c) 2010 Jeroen T. Vermeulen\n"
+      "Written by Jeroen T. Vermeulen\n"
       "This program is free software, and is available for use under the GNU\n"
-      "General Public License (GPL).\n";
+      "General Public License (GPL).\n"
+      "See http://pqxx.org/development/swapspace\n"
+      "This is a fork of the original project by Jacob Adams hosted at:\n"
+	  "https://github.com/Tookmund/swapspace\n";
 
 
 #ifndef NO_CONFIG
-static char configfile[PATH_MAX] = "/etc/swapspace.conf";
+static char configfile[PATH_MAX] = ETCPREFIX"/etc/swapspace.conf";
 
 static char *set_configfile(long long dummy)
 {
@@ -62,6 +67,13 @@ static char *set_inspect(long long dummy)
   return NULL;
 }
 
+bool zero = false;
+static char *set_zero(long long dummy)
+{
+  zero = true;
+  return NULL;
+}
+
 enum argtype { at_none, at_num, at_str };
 struct option
 {
@@ -116,7 +128,9 @@ static const struct option options[] =
   { "verbose",		'v', at_none, 0, 0, set_verbose,
   "Print lots of debug information" },
   { "version",		'V', at_none, 0, 0, set_version,
-  "Print version number and exit" }
+  "Print version number and exit" },
+  { "zero",			'z', at_none, 0, 0, set_zero,
+  "Force swapfile allocation by manually filling with zeros" }
 };
 
 
@@ -127,7 +141,7 @@ static int optcmp(const void *o1, const void *o2)
 }
 
 
-#ifndef NDEBUG
+#ifndef NO_DEBUG
 static bool options_okay(void)
 {
   static const int num_opts = sizeof(options)/sizeof(*options);
@@ -171,7 +185,7 @@ static bool options_okay(void)
   }
   return true;
 }
-#endif	// NDEBUG
+#endif	// NO_DEBUG
 
 static const char *argproto(int opt, bool shortopt)
 {
@@ -245,7 +259,8 @@ static void short_usage(void)
 
 char *set_version(long long dummy)
 {
-  puts("swapspace " VERSION ", " DATE);
+  if (PACKAGE_VERSION) puts(PACKAGE_STRING);
+  else puts("swapspace unknown");
   puts(copyright);
   exit(EXIT_SUCCESS);
 }
