@@ -2,7 +2,8 @@
 This file is part of Swapspace.
 
 Copyright (C) 2005,2006, Software Industry Industry Promotion Agency (SIPA)
-Written by Jeroen T. Vermeulen <jtv@xs4all.nl>.
+Copyright (C) 2010, Jeroen T. Vermeulen
+Written by Jeroen T. Vermeulen.
 
 Swapspace is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -54,7 +55,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 #define O_NOFOLLOW 0
 #endif
 
-static char swappath[PATH_MAX] = "/var/lib/swapspace";
+static char swappath[PATH_MAX] = VARPREFIX"/var/lib/swapspace";
 static size_t swappath_len;
 
 
@@ -331,7 +332,11 @@ static memsize_t write_data(int fd, memsize_t bytes, bool persevere)
 {
   // Round upwards to multiple of page size
   bytes = ext_to_page(bytes);
-
+#ifdef HAVE_PFALLOCATE
+ // Have posix_fallocate().  Much faster way of getting the file populated.
+ if (!zero && posix_fallocate(fd, 0, bytes) == 0) return bytes;
+ // We have no error backchannel here, so on failure, try the old way.
+#endif
   /* Zero buffer before using it to write data to swapfile.  This doesn't do
    * much for security (if an attacker can get to your swapfiles you don't have
    * a lot of that anyway) but perhaps some filesystems may recognize all-zero
@@ -471,6 +476,8 @@ static memsize_t filesize(const char name[])
   if (unlikely(pos == -1))
     log_perr_str(LOG_WARNING, "Can't determine size of", name, errno);
 
+  close(fd);
+
   return pos;
 }
 
@@ -698,7 +705,10 @@ static bool retire_swapfile(int file)
   unlink(namebuf);
 
 #ifndef NO_CONFIG
-  if (fd != -1) write_data(fd, swapfiles[file].size, true);
+  if (fd != -1) {
+    write_data(fd, swapfiles[file].size, true);
+    close(fd);
+  }
 #endif
 
   swapfiles[file].size = 0;
